@@ -89,20 +89,22 @@ zlib_patchlevel=1
 libogg_version=1.3.4
 libogg_patchlevel=0.1
 libvorbis_version=1.3.7
-libvorbis_patchlevel=2
+libvorbis_patchlevel=3
 ffmpeg3_version=3.2.14
 ffmpeg3_patchlevel=1~deb9u1
-ffmpeg_version=5.1.6
-ffmpeg_patchlevel=0+deb12u1
-libflac_version=1.4.3+ds
-libflac_patchlevel=2.1
+ffmpeg5_version=5.1.6
+ffmpeg5_patchlevel=0+deb12u1
+ffmpeg_version=7.1.1
+ffmpeg_patchlevel=1
+libflac_version=1.5.0+ds
+libflac_patchlevel=2
 id3lib_version=3.8.3
 id3lib_patchlevel=18
-taglib_version=2.0.2
+taglib_version=2.1.1
 chromaprint_version=1.5.1
-chromaprint_patchlevel=6
+chromaprint_patchlevel=7
 mp4v2_version=2.1.3
-utfcpp_version=4.0.5
+utfcpp_version=4.0.6
 
 verify_not_in_srcdir() {
   if test -f CMakeLists.txt; then
@@ -119,6 +121,107 @@ verify_in_srcdir() {
   fi
 }
 
+download_and_extract_qt() {
+  local _qtarch=$1
+  if test -z "$_qtarch"; then
+    if test "$compiler" = "cross-android"; then
+      if test "$_android_abi" = "x86_64"; then
+        _qtarch=android_x86_64
+      elif test "$_android_abi" = "arm64-v8a"; then
+        _qtarch=android_arm64_v8a
+      else
+        _qtarch=android_armv7
+      fi
+    elif test $kernel = "Linux"; then
+      _qtarch=gcc_64
+    elif test $kernel = "Darwin"; then
+      _qtarch=macos
+    elif test $kernel = "MINGW"; then
+      _qtarch=mingw_64
+    fi
+  fi
+  if test -n "$_qtarch" && ! test -d qt-${qt_version}/${qt_version}/${_qtarch}; then
+    mkdir -p qt-${qt_version}
+    cd qt-${qt_version}
+    if test $qt_version = "6.5.3"; then
+      case "$_qtarch" in
+        android_x86_64)
+          for m in qttranslations qttools qtsvg qtdeclarative qtbase; do
+            fn=6.5.3-0-202309260341${m}-Linux-RHEL_8_4-Clang-Android-Android_ANY-X86_64.7z
+            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_x86_64/qt.qt6.653.android_x86_64/$fn
+          done
+          for m in qtmultimedia qtimageformats; do
+            fn=qt.qt6.653.addons.${m}.android_x86_64/6.5.3-0-202309260341${m}-Linux-RHEL_8_4-Clang-Android-Android_ANY-X86_64.7z
+            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_x86_64/$fn
+          done
+          ;;
+        android_arm64_v8a)
+          for m in qttranslations qttools qtsvg qtdeclarative qtbase; do
+            fn=6.5.3-0-202309260341${m}-MacOS-MacOS_12-Clang-Android-Android_ANY-ARM64.7z
+            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_arm64_v8a/qt.qt6.653.android_arm64_v8a/$fn
+          done
+          for m in qtmultimedia qtimageformats; do
+            fn=qt.qt6.653.addons.${m}.android_arm64_v8a/6.5.3-0-202309260341${m}-MacOS-MacOS_12-Clang-Android-Android_ANY-ARM64.7z
+            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_arm64_v8a/$fn
+          done
+          ;;
+        android_armv7)
+          for m in qttranslations qttools qtsvg qtdeclarative qtbase; do
+            fn=6.5.3-0-202309260341${m}-Windows-Windows_10_22H2-Clang-Android-Android_ANY-ARMv7.7z
+            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_armv7/qt.qt6.653.android_armv7/$fn
+          done
+          for m in qtmultimedia qtimageformats; do
+            fn=qt.qt6.653.addons.${m}.android_armv7/6.5.3-0-202309260341${m}-Windows-Windows_10_22H2-Clang-Android-Android_ANY-ARMv7.7z
+            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_armv7/$fn
+          done
+          ;;
+        gcc_64)
+          for m in qttranslations qttools qtsvg qtdeclarative qtbase qtwayland; do
+            fn=6.5.3-0-202309260341${m}-Linux-RHEL_8_4-GCC-Linux-RHEL_8_4-X86_64.7z
+            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/desktop/qt6_653/qt.qt6.653.gcc_64/$fn
+          done
+          $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/desktop/qt6_653/qt.qt6.653.gcc_64/6.5.3-0-202309260341icu-linux-Rhel7.2-x64.7z
+          for m in qtmultimedia qtimageformats; do
+            fn=qt.qt6.653.addons.${m}.gcc_64/6.5.3-0-202309260341${m}-Linux-RHEL_8_4-GCC-Linux-RHEL_8_4-X86_64.7z
+            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/desktop/qt6_653/$fn
+          done
+          ;;
+        macos)
+          for m in qttranslations qttools qtsvg qtdeclarative qtbase; do
+            fn=6.5.3-0-202309260341${m}-MacOS-MacOS_12-Clang-MacOS-MacOS_12-X86_64-ARM64.7z
+            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/mac_x64/desktop/qt6_653/qt.qt6.653.clang_64/$fn
+          done
+          for m in qtmultimedia qtimageformats; do
+            fn=qt.qt6.653.addons.${m}.clang_64/6.5.3-0-202309260341${m}-MacOS-MacOS_12-Clang-MacOS-MacOS_12-X86_64-ARM64.7z
+            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/mac_x64/desktop/qt6_653/$fn
+          done
+          ;;
+        mingw_64)
+          for m in qttranslations qttools qtsvg qtdeclarative qtbase; do
+            fn=6.5.3-0-202309260341${m}-Windows-Windows_10_22H2-Mingw-Windows-Windows_10_22H2-X86_64.7z
+            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/windows_x86/desktop/qt6_653/qt.qt6.653.win64_mingw/$fn
+          done
+          for m in opengl32sw-64-mesa_11_2_2-signed_sha256 d3dcompiler_47-x64 MinGW-w64-x86_64-11.2.0-release-posix-seh-rt_v9-rev1-runtime; do
+            fn=6.5.3-0-202309260341${m}.7z
+            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/windows_x86/desktop/qt6_653/qt.qt6.653.win64_mingw/$fn
+          done
+          for m in qtmultimedia qtimageformats; do
+            fn=qt.qt6.653.addons.${m}.win64_mingw/6.5.3-0-202309260341${m}-Windows-Windows_10_22H2-Mingw-Windows-Windows_10_22H2-X86_64.7z
+            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/windows_x86/desktop/qt6_653/$fn
+          done
+          for m in mingw-w64-x86_64-11.2.0-release-posix-seh-rt_v9-rev3; do
+            fn=9.0.0-1-202203221220${m}.7z
+            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/windows_x86/desktop/tools_mingw90/qt.tools.win64_mingw900/$fn
+          done
+          ;;
+      esac
+      for fn in *.7z; do 7za x $fn; done
+      rm -f *.7z
+    fi
+    cd -
+  fi
+}
+
 # The environment variable KID3_HOMEBREW_PKGS can be set to install packages
 # needed to build using Homebrew, if brew is not yet available a local instance
 # is installed.
@@ -173,7 +276,7 @@ kid3 (${NEWVER}-0) unstable; urgency=low\n\n  * New upstream release.\n\n\
   if test "$4" = "--finalize"; then
     sed -i "s/^\(Version: \+\).*$/\1${NEWVER}/" kid3.spec
     OLDCODE=$(sed -n "s/ \+set(QT_ANDROID_APP_VERSION_CODE \([0-9]\+\))/\1/p" CMakeLists.txt)
-    NEWCODE=$[ $OLDCODE + 1 ]
+    NEWCODE=$[ $OLDCODE + 2 ]
     sed -i "s/\( \+set(QT_ANDROID_APP_VERSION_CODE \)\([0-9]\+\))/\1$NEWCODE)/" CMakeLists.txt
   fi
   sed -i "s/^Copyright 2003-[0-9]\+ Urs Fleisch <ufleisch@users.sourceforge.net>$/Copyright 2003-${DATE_Y} Urs Fleisch <ufleisch@users.sourceforge.net>/" deb/copyright
@@ -282,7 +385,8 @@ set -e
 (cd macos_qt5_build && \
    rm -f kid3/*-Darwin.dmg && \
    COMPILER=cross-macos \
-   QTPREFIX=$HOME/Development/Qt5.15.2-mac/5.15.2/clang_64 \
+   QTPREFIX=$HOME/Development/Qt5.9.7-mac/5.9.7/clang_64 \
+   QTBINARYDIR=$HOME/Development/Qt5.9.7-linux/5.9.7/gcc_64/bin \
    OSXPREFIX=/opt/osxcross/target \
    ../kid3/build.sh && \
    origdmg=(kid3/*-Darwin.dmg) && \
@@ -300,7 +404,7 @@ set -e
 (cd android_arm64_build && \
    PATH=/opt/cmake/bin:$PATH \
    COMPILER=cross-android \
-   QTPREFIX=$HOME/Development/Development/Qt6.5.3-android64/6.5.3/android_arm64_v8a \
+   QTPREFIX=$HOME/Development/Qt6.5.3-android64/6.5.3/android_arm64_v8a \
    QTBINARYDIR=$HOME/Development/Qt6.5.3-linux/6.5.3/gcc_64/bin \
    JAVA_HOME=/usr/lib/jvm/java-17-openjdk-amd64 \
    ANDROID_SDK_ROOT=$HOME/Development/android-sdk \
@@ -424,6 +528,17 @@ if test "$1" = "clean"; then
   exit 0
 fi
 
+if test "$1" = "getqt"; then
+  if which wget >/dev/null; then
+    DOWNLOAD=wget
+  else
+    DOWNLOAD="curl -skfLO"
+  fi
+  compiler=${COMPILER:-gcc}
+  download_and_extract_qt
+  exit 0
+fi
+
 # End of subtasks
 
 verify_not_in_srcdir
@@ -471,7 +586,7 @@ else
 fi
 
 if test "$compiler" = "cross-android" -o "$compiler" = "gcc-self-contained" && test "$qt_nr" -ge 60000; then
-  openssl_version=3.0.9
+  openssl_version=3.0.17
 elif test "$qt_nr" -ge 51204; then
   # Since Qt 5.12.4, OpenSSL 1.1.1 is supported
   openssl_version=1.1.1g
@@ -515,6 +630,10 @@ elif test "$compiler" = "cross-macos"; then
   _crossprefix=${cross_host}-
   # e.g. $osxprefix/SDK/MacOSX10.13.sdk
   osxsdk=($osxprefix/SDK/*.sdk)
+  # install_name_tool: fatal error: the __LINKEDIT segment does not cover the end of the file
+  # when fixing up libacoustidimport.dylib with FFmpeg 7.1.1
+  ffmpeg_version=$ffmpeg5_version
+  ffmpeg_patchlevel=$ffmpeg5_patchlevel
 fi
 if test "$compiler" = "cross-android"; then
   _java_root=${JAVA_HOME:-/usr/lib/jvm/java-8-openjdk-amd64}
@@ -697,6 +816,10 @@ fixcmakeinst() {
       rm -rf usr
       mv msys32/usr .
       rmdir msys32
+    elif test -d MSys2; then
+      rm -rf usr
+      mv MSys2/usr .
+      rmdir MSys2
     fi
     cd ..
   fi
@@ -1021,80 +1144,6 @@ download_openssl() {
   cd -
 }
 
-download_and_extract_qt() {
-  if ! test -d qt-${qt_version}; then
-    mkdir qt-${qt_version}
-    cd qt-${qt_version}
-    if test $qt_version = "6.5.3"; then
-      if test "$compiler" = "cross-android"; then
-        if test "$_android_abi" = "x86_64"; then
-          for m in qttranslations qttools qtsvg qtdeclarative qtbase; do
-            fn=6.5.3-0-202309260341${m}-Linux-RHEL_8_4-Clang-Android-Android_ANY-X86_64.7z
-            wget https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_x86_64/qt.qt6.653.android_x86_64/$fn
-          done
-          for m in qtmultimedia qtimageformats; do
-            fn=qt.qt6.653.addons.${m}.android_x86_64/6.5.3-0-202309260341${m}-Linux-RHEL_8_4-Clang-Android-Android_ANY-X86_64.7z
-            wget https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_x86_64/$fn
-          done
-        elif test "$_android_abi" = "arm64-v8a"; then
-          for m in qttranslations qttools qtsvg qtdeclarative qtbase; do
-            fn=6.5.3-0-202309260341${m}-MacOS-MacOS_12-Clang-Android-Android_ANY-ARM64.7z
-            wget https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_arm64_v8a/qt.qt6.653.android_arm64_v8a/$fn
-          done
-          for m in qtmultimedia qtimageformats; do
-            fn=qt.qt6.653.addons.${m}.android_arm64_v8a/6.5.3-0-202309260341${m}-MacOS-MacOS_12-Clang-Android-Android_ANY-ARM64.7z
-            wget https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_arm64_v8a/$fn
-          done
-        else
-          for m in qttranslations qttools qtsvg qtdeclarative qtbase; do
-            fn=6.5.3-0-202309260341${m}-Windows-Windows_10_22H2-Clang-Android-Android_ANY-ARMv7.7z
-            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_armv7/qt.qt6.653.android_armv7/$fn
-          done
-          for m in qtmultimedia qtimageformats; do
-            fn=qt.qt6.653.addons.${m}.android_armv7/6.5.3-0-202309260341${m}-Windows-Windows_10_22H2-Clang-Android-Android_ANY-ARMv7.7z
-            $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/android/qt6_653_armv7/$fn
-          done
-        fi
-      elif test $kernel = "Linux"; then
-        for m in qttranslations qttools qtsvg qtdeclarative qtbase qtwayland; do
-          fn=6.5.3-0-202309260341${m}-Linux-RHEL_8_4-GCC-Linux-RHEL_8_4-X86_64.7z
-          $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/desktop/qt6_653/qt.qt6.653.gcc_64/$fn
-        done
-        $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/desktop/qt6_653/qt.qt6.653.gcc_64/6.5.3-0-202309260341icu-linux-Rhel7.2-x64.7z
-        for m in qtmultimedia qtimageformats; do
-          fn=qt.qt6.653.addons.${m}.gcc_64/6.5.3-0-202309260341${m}-Linux-RHEL_8_4-GCC-Linux-RHEL_8_4-X86_64.7z
-          $DOWNLOAD https://download.qt.io/online/qtsdkrepository/linux_x64/desktop/qt6_653/$fn
-        done
-      elif test $kernel = "Darwin"; then
-        for m in qttranslations qttools qtsvg qtdeclarative qtbase; do
-          fn=6.5.3-0-202309260341${m}-MacOS-MacOS_12-Clang-MacOS-MacOS_12-X86_64-ARM64.7z
-          $DOWNLOAD https://download.qt.io/online/qtsdkrepository/mac_x64/desktop/qt6_653/qt.qt6.653.clang_64/$fn
-        done
-        for m in qtmultimedia qtimageformats; do
-          fn=qt.qt6.653.addons.${m}.clang_64/6.5.3-0-202309260341${m}-MacOS-MacOS_12-Clang-MacOS-MacOS_12-X86_64-ARM64.7z
-          $DOWNLOAD https://download.qt.io/online/qtsdkrepository/mac_x64/desktop/qt6_653/$fn
-        done
-      elif test $kernel = "MINGW"; then
-        for m in qttranslations qttools qtsvg qtdeclarative qtbase; do
-          fn=6.5.3-0-202309260341${m}-Windows-Windows_10_22H2-Mingw-Windows-Windows_10_22H2-X86_64.7z
-          $DOWNLOAD https://download.qt.io/online/qtsdkrepository/windows_x86/desktop/qt6_653/qt.qt6.653.win64_mingw/$fn
-        done
-        for m in opengl32sw-64-mesa_11_2_2-signed_sha256 d3dcompiler_47-x64 MinGW-w64-x86_64-11.2.0-release-posix-seh-rt_v9-rev1-runtime; do
-          fn=6.5.3-0-202309260341${m}.7z
-          $DOWNLOAD https://download.qt.io/online/qtsdkrepository/windows_x86/desktop/qt6_653/qt.qt6.653.win64_mingw/$fn
-        done
-        for m in qtmultimedia qtimageformats; do
-          fn=qt.qt6.653.addons.${m}.win64_mingw/6.5.3-0-202309260341${m}-Windows-Windows_10_22H2-Mingw-Windows-Windows_10_22H2-X86_64.7z
-          $DOWNLOAD https://download.qt.io/online/qtsdkrepository/windows_x86/desktop/qt6_653/$fn
-        done
-      fi
-      for fn in *.7z; do 7za x $fn; done
-      rm -f *.7z
-    fi
-    cd -
-  fi
-}
-
 # Extract and patch sources
 
 extract_utfcpp() {
@@ -1373,13 +1422,6 @@ if test "$compiler" = "cross-android"; then
   fi
   extract_binary_archive $BIN_ARCHIVE_DIR/taglib-${taglib_version}.tgz
 
-  # Set a QTPREFIX starting with "$(pwd)/qt-", e.g. $(pwd)/qt-6.5.3/6.5.3/android_arm64_v8a
-  # or $(pwd)/qt-6.5.3/6.5.3/android_armv7 or $(pwd)/qt-6.5.3/6.5.3/android_x86_64
-  # in order to download Qt binaries to the given $QTPREFIX if it does not already exist.
-  if test "${QTPREFIX%%/qt-*}" = "$(pwd)" -a ! -d "$QTPREFIX"; then
-    download_and_extract_qt
-  fi
-
 else #  cross-android
 
   if ( test "$compiler" = "gcc-self-contained" || test "$compiler" = "gcc-debug" ) \
@@ -1462,7 +1504,7 @@ else #  cross-android
     echo "### Building libogg"
 
     cd libogg-${libogg_version}/
-    test -f build.ninja || eval cmake -DBUILD_SHARED_LIBS=OFF $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
+    test -f build.ninja || eval cmake -DCMAKE_POLICY_VERSION_MINIMUM=3.5 -DBUILD_SHARED_LIBS=OFF $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
     DESTDIR=`pwd`/inst ninja install
     fixcmakeinst
     cd inst
@@ -1477,7 +1519,7 @@ else #  cross-android
     echo "### Building libvorbis"
 
     cd libvorbis-${libvorbis_version}/
-    test -f build.ninja || eval cmake -DBUILD_SHARED_LIBS=OFF -DCMAKE_PREFIX_PATH=$thisdir/buildroot/usr/local $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
+    test -f build.ninja || eval cmake -DCMAKE_POLICY_VERSION_MINIMUM=3.5 -DBUILD_SHARED_LIBS=OFF -DCMAKE_PREFIX_PATH=$thisdir/buildroot/usr/local $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
     DESTDIR=`pwd`/inst ninja install
     fixcmakeinst
     cd inst
@@ -1612,6 +1654,10 @@ else #  cross-android
     if test $kernel = "Darwin" && test $(uname -m) = "arm64"; then
       AV_CONFIGURE_OPTIONS="$AV_CONFIGURE_OPTIONS --arch=$ARCH"
     fi
+    if test -z "${ffmpeg_version##5.*}"; then
+      # No longer supported with FFmpeg 7
+      AV_CONFIGURE_OPTIONS="$AV_CONFIGURE_OPTIONS --enable-rdft"
+    fi
     AV_CONFIGURE_OPTIONS="$AV_CONFIGURE_OPTIONS $AV_BUILD_OPTION"
     ./configure \
       --disable-shared \
@@ -1625,7 +1671,6 @@ else #  cross-android
       --disable-demuxers \
       --disable-sse \
       --disable-doc \
-      --enable-rdft \
       --enable-demuxer=aac \
       --enable-demuxer=ac3 \
       --enable-demuxer=ape \
@@ -1708,7 +1753,7 @@ else #  cross-android
 
     # The zlib library path was added for MinGW-builds GCC 4.7.2.
     cd chromaprint-${chromaprint_version}/
-    test -f build.ninja || eval cmake -DBUILD_SHARED_LIBS=OFF -DBUILD_TESTS=OFF $CHROMAPRINT_ZLIB_OPTION -DFFMPEG_ROOT=$thisdir/buildroot/usr/local $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
+    test -f build.ninja || eval cmake -DCMAKE_POLICY_VERSION_MINIMUM=3.5 -DBUILD_SHARED_LIBS=OFF -DBUILD_TESTS=OFF $CHROMAPRINT_ZLIB_OPTION -DFFMPEG_ROOT=$thisdir/buildroot/usr/local $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
     DESTDIR=`pwd`/inst ninja install
     fixcmakeinst
     cd inst
@@ -1723,7 +1768,7 @@ else #  cross-android
     echo "### Building mp4v2"
 
     cd mp4v2-${mp4v2_version}/
-    test -f build.ninja || eval cmake -DBUILD_SHARED=OFF -DBUILD_UTILS=OFF -DBUILD_SHARED_LIBS=OFF $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
+    test -f build.ninja || eval cmake -DCMAKE_POLICY_VERSION_MINIMUM=3.5 -DBUILD_SHARED=OFF -DBUILD_UTILS=OFF -DBUILD_SHARED_LIBS=OFF $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
     DESTDIR=`pwd`/inst ninja install
     fixcmakeinst
     cd inst
@@ -1732,13 +1777,27 @@ else #  cross-android
   fi
   extract_binary_archive $BIN_ARCHIVE_DIR/mp4v2-${mp4v2_version}.tgz
 
-  # Set a QTPREFIX starting with "$(pwd)/qt-", e.g. $(pwd)/qt-6.5.3/6.5.3/gcc_64
-  # for Linux or $(pwd)/qt-6.5.3/6.5.3/macos for macOS in order to download Qt
-  # binaries to the given $QTPREFIX if it does not already exist.
-  if test "${QTPREFIX%%/qt-*}" = "$(pwd)" -a ! -d "$QTPREFIX"; then
-    download_and_extract_qt
-  fi
 fi # cross-android, else
+
+# Set a QTPREFIX starting with "$(pwd)/qt-", e.g. $(pwd)/qt-6.5.3/6.5.3/gcc_64
+# for Linux or $(pwd)/qt-6.5.3/6.5.3/macos for macOS or
+# $(pwd)/qt-6.5.3/6.5.3/android_arm64_v8a or
+# $(pwd)/qt-6.5.3/6.5.3/android_armv7 or $(pwd)/qt-6.5.3/6.5.3/android_x86_64
+# in order to download Qt binaries to the given $QTPREFIX if it does not already exist.
+if test "${QTPREFIX%%/qt-*}" = "$(pwd)"; then
+  download_and_extract_qt
+fi
+
+# Set QTBINARYDIR starting with "$(pwd)/qt-", e.g. $(pwd)/qt-6.5.3/6.5.3/gcc_64/bin
+# to dowload Qt binaries for Linux.
+if test "${QTBINARYDIR%%/qt-*}" = "$(pwd)"; then
+  _qt_arch=${QTBINARYDIR%%/bin}
+  _qt_arch=${_qt_arch##*/}
+  if test -n "$_qt_arch"; then
+    download_and_extract_qt $_qt_arch
+  fi
+fi
+
 fi # libs
 
 if [[ $target = *"package"* ]]; then
