@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 9 Jan 2003
  *
- * Copyright (C) 2003-2018  Urs Fleisch
+ * Copyright (C) 2003-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -54,47 +54,47 @@ public:
   /**
    * Destructor.
    */
-  virtual ~Kid3MainWindow() override = default;
+  ~Kid3MainWindow() override = default;
 
   /**
    * Init menu and toolbar actions.
    */
-  virtual void initActions() override;
+  void initActions() override;
 
   /**
    * Get keyboard shortcuts.
    * @return mapping of action names to key sequences.
    */
-  virtual QMap<QString, QKeySequence> shortcutsMap() const override;
+  QMap<QString, QKeySequence> shortcutsMap() const override;
 
   /**
    * Add directory to recent files list.
    *
    * @param dirName path to directory
    */
-  virtual void addDirectoryToRecentFiles(const QString& dirName) override;
+  void addDirectoryToRecentFiles(const QString& dirName) override;
 
   /**
    * Read settings from the configuration.
    */
-  virtual void readConfig() override;
+  void readConfig() override;
 
   /**
    * Store geometry and recent files in settings.
    */
-  virtual void saveConfig() override;
+  void saveConfig() override;
 
   /**
    * Get action for Settings/Auto Hide Tags.
    * @return action.
    */
-  virtual QAction* autoHideTagsAction() override;
+  QAction* autoHideTagsAction() override;
 
   /**
    * Get action for Settings/Hide Picture.
    * @return action.
    */
-  virtual QAction* showHidePictureAction() override;
+  QAction* showHidePictureAction() override;
 
   /**
    * Set main window caption.
@@ -102,7 +102,7 @@ public:
    * @param caption caption without application name
    * @param modified true if any file is modified
    */
-  virtual void setWindowCaption(const QString& caption, bool modified) override;
+  void setWindowCaption(const QString& caption, bool modified) override;
 
 protected:
   /**
@@ -110,7 +110,7 @@ protected:
    *
    * @param ce close event
    */
-  virtual void closeEvent(QCloseEvent* ce) override;
+  void closeEvent(QCloseEvent* ce) override;
 
 private slots:
   /**
