@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 29 Dec 2011
  *
- * Copyright (C) 2011-2018  Urs Fleisch
+ * Copyright (C) 2011-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -62,14 +62,14 @@ public:
   /**
    * Destructor.
    */
-  virtual ~ShortcutsModel() override = default;
+  ~ShortcutsModel() override = default;
 
   /**
    * Get item flags for index.
    * @param index model index
    * @return item flags
    */
-  virtual Qt::ItemFlags flags(const QModelIndex& index) const override;
+  Qt::ItemFlags flags(const QModelIndex& index) const override;
 
   /**
    * Get data for a given role.
@@ -77,8 +77,8 @@ public:
    * @param role item data role
    * @return data for role
    */
-  virtual QVariant data(const QModelIndex& index,
-                        int role = Qt::DisplayRole) const override;
+  QVariant data(const QModelIndex& index,
+                int role = Qt::DisplayRole) const override;
 
   /**
    * Set data for a given role.
@@ -87,8 +87,8 @@ public:
    * @param role item data role
    * @return true if successful
    */
-  virtual bool setData(const QModelIndex& index, const QVariant& value,
-                       int role = Qt::EditRole) override;
+  bool setData(const QModelIndex& index, const QVariant& value,
+               int role = Qt::EditRole) override;
 
   /**
    * Get data for header section.
@@ -97,22 +97,22 @@ public:
    * @param role item data role
    * @return header data for role
    */
-  virtual QVariant headerData(int section, Qt::Orientation orientation,
-                              int role = Qt::DisplayRole) const override;
+  QVariant headerData(int section, Qt::Orientation orientation,
+                      int role = Qt::DisplayRole) const override;
 
   /**
    * Get number of rows.
    * @param parent parent model index
    * @return number of rows, if parent is valid number of children
    */
-  virtual int rowCount(const QModelIndex& parent = QModelIndex()) const override;
+  int rowCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Get number of columns.
    * @param parent parent model index
    * @return number of columns for children of given \a parent
    */
-  virtual int columnCount(const QModelIndex& parent = QModelIndex()) const override;
+  int columnCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Get model index of item.
@@ -121,15 +121,15 @@ public:
    * @param parent index of parent item
    * @return model index of item
    */
-  virtual QModelIndex index(int row, int column,
-                            const QModelIndex& parent = QModelIndex()) const override;
+  QModelIndex index(int row, int column,
+                    const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Get parent of item.
    * @param index model index of item
    * @return model index of parent item
    */
-  virtual QModelIndex parent(const QModelIndex& index) const override;
+  QModelIndex parent(const QModelIndex& index) const override;
 
   /**
    * Register an action.
@@ -145,7 +145,7 @@ public:
    * @param action action to be removed from model
    * @param context context of action
    */
-  void unregisterAction(QAction* action, const QString& context);
+  void unregisterAction(const QAction* action, const QString& context);
 
   /**
    * Get mapping of shortcut names to key sequences.
