@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 2 Jan 2018
  *
- * Copyright (C) 2018  Urs Fleisch
+ * Copyright (C) 2018-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -44,14 +44,14 @@ public:
   /**
    * Destructor.
    */
-  virtual ~StarRatingMappingsModel() override = default;
+  ~StarRatingMappingsModel() override = default;
 
   /**
    * Get item flags for index.
    * @param index model index
    * @return item flags
    */
-  virtual Qt::ItemFlags flags(const QModelIndex& index) const override;
+  Qt::ItemFlags flags(const QModelIndex& index) const override;
 
   /**
    * Get data for a given role.
@@ -59,8 +59,8 @@ public:
    * @param role item data role
    * @return data for role
    */
-  virtual QVariant data(const QModelIndex& index,
-                        int role = Qt::DisplayRole) const override;
+  QVariant data(const QModelIndex& index,
+                int role = Qt::DisplayRole) const override;
 
   /**
    * Set data for a given role.
@@ -69,8 +69,8 @@ public:
    * @param role item data role
    * @return true if successful
    */
-  virtual bool setData(const QModelIndex& index, const QVariant& value,
-                       int role = Qt::EditRole) override;
+  bool setData(const QModelIndex& index, const QVariant& value,
+               int role = Qt::EditRole) override;
 
   /**
    * Get data for header section.
@@ -79,16 +79,16 @@ public:
    * @param role item data role
    * @return header data for role
    */
-  virtual QVariant headerData(int section, Qt::Orientation orientation,
-                              int role = Qt::DisplayRole) const override;
+  QVariant headerData(int section, Qt::Orientation orientation,
+                      int role = Qt::DisplayRole) const override;
 
   /**
    * Set data for header section.
    * Not supported.
    * @return false
    */
-  virtual bool setHeaderData(int, Qt::Orientation, const QVariant&,
-                             int = Qt::EditRole) override { return false; }
+  bool setHeaderData(int, Qt::Orientation, const QVariant&,
+                     int = Qt::EditRole) override { return false; }
 
   /**
    * Get number of rows.
@@ -96,7 +96,7 @@ public:
    * @return number of rows,
    * if parent is valid number of children (0 for table models)
    */
-  virtual int rowCount(const QModelIndex& parent = QModelIndex()) const override;
+  int rowCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Get number of columns.
@@ -104,7 +104,7 @@ public:
    * @return number of columns,
    * if parent is valid number of children (0 for table models)
    */
-  virtual int columnCount(const QModelIndex& parent = QModelIndex()) const override;
+  int columnCount(const QModelIndex& parent = QModelIndex()) const override;
 
   /**
    * Insert rows.
@@ -114,8 +114,8 @@ public:
    * @param parent parent model index, invalid for table models
    * @return true if successful
    */
-  virtual bool insertRows(int row, int count,
-                          const QModelIndex& parent = QModelIndex()) override;
+  bool insertRows(int row, int count,
+                  const QModelIndex& parent = QModelIndex()) override;
 
   /**
    * Remove rows.
@@ -124,8 +124,8 @@ public:
    * @param parent parent model index, invalid for table models
    * @return true if successful
    */
-  virtual bool removeRows(int row, int count,
-                          const QModelIndex& parent = QModelIndex()) override;
+  bool removeRows(int row, int count,
+                  const QModelIndex& parent = QModelIndex()) override;
 
   /**
    * Set the model from the star count mappings.
