@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 29 Jun 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,9 +24,9 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef USERACTIONSCONFIG_H
-#define USERACTIONSCONFIG_H
+#pragma once
 
+#include <QVariantList>
 #include "generalconfig.h"
 #include "kid3api.h"
 
@@ -147,21 +147,21 @@ public:
   /**
    * Destructor.
    */
-  virtual ~UserActionsConfig();
+  ~UserActionsConfig() override = default;
 
   /**
    * Persist configuration.
    *
    * @param config configuration
    */
-  virtual void writeToConfig(ISettings* config) const;
+  void writeToConfig(ISettings* config) const override;
 
   /**
    * Read persisted configuration.
    *
    * @param config configuration
    */
-  virtual void readFromConfig(ISettings* config);
+  void readFromConfig(ISettings* config) override;
 
   /** Get list of context menu commands. */
   QList<MenuCommand> contextMenuCommands() const {
@@ -177,6 +177,12 @@ public:
   /** Set list of context menu commands from variant list. */
   void setContextMenuCommandVariantList(const QVariantList& lst);
 
+  /**
+   * Set default user actions.
+   * @param upgradeOnly if true only upgrade configuration with new actions
+   */
+  void setDefaultUserActions(bool upgradeOnly = false);
+
 signals:
   /** Emitted when commands changed. */
   void contextMenuCommandsChanged();
@@ -190,5 +196,3 @@ private:
   /** Index in configuration storage */
   static int s_index;
 };
-
-#endif
