@@ -30,9 +30,10 @@
 #include <QRegularExpression>
 #include <QMap>
 #include <QList>
+#include <QStringList>
 #include "kid3api.h"
 
-class FrameCollection;
+class TrackData;
 
 /**
  * Import parser.
@@ -61,7 +62,7 @@ public:
    *             behind current match (to be used for next call)
    * @return true if tags found (pos is index behind match).
    */
-  bool getNextTags(const QString& text, FrameCollection& frames, int& pos);
+  bool getNextTags(const QString& text, TrackData& frames, int& pos);
 
   /**
    * Get list with track durations.
@@ -70,12 +71,21 @@ public:
    */
   QList<int> getTrackDurations() const { return m_trackDuration; }
 
+  /**
+   * Get list with values accumulated for %{__return}.
+   * @return accumulated return values.
+   */
+  QStringList getReturnValues() const { return m_returnValues; }
+
   /**
    * Get help text for format codes supported by setFormat().
    *
+   * @param onlyRows if true only the tr elements are returned,
+   *                 not the surrounding table
+   *
    * @return help text.
    */
-  static QString getFormatToolTip();
+  static QString getFormatToolTip(bool onlyRows = false);
 
 private:
   /** track regexp pattern */
@@ -86,6 +96,7 @@ private:
   int m_trackIncrNr;
   QMap<QString, int> m_codePos;
   QList<int> m_trackDuration;
+  QStringList m_returnValues;
   /** true if automatic track number incrementing is used */
   bool m_trackIncrEnabled;
 };
