@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Oct 2006
  *
- * Copyright (C) 2006-2018  Urs Fleisch
+ * Copyright (C) 2006-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -91,12 +91,16 @@ QString ServerImporter::replaceHtmlEntities(QString str)
 
   QRegularExpression numEntityRe(QLatin1String("&#(x?\\d+);"));
   auto it = numEntityRe.globalMatch(str);
+  int numCharsRemoved = 0;
   while (it.hasNext()) {
     auto match = it.next();
     QString codeStr = match.captured(1);
     int code = codeStr.startsWith(QLatin1Char('x'))
         ? codeStr.mid(1).toInt(nullptr, 16) : codeStr.toInt();
-    str.replace(match.capturedStart(), match.capturedLength(), QChar(code));
+    int pos = match.capturedStart() - numCharsRemoved;
+    int len = match.capturedLength();
+    str.replace(pos, len, QChar(code));
+    numCharsRemoved += len - 1;
   }
   return str;
 }
@@ -147,8 +151,7 @@ void AlbumListModel::getItem(int row, QString& text,
 void AlbumListModel::appendItem(const QString& text,
                                 const QString& category, const QString& id)
 {
-  int row = rowCount();
-  if (insertRow(row)) {
+  if (int row = rowCount(); insertRow(row)) {
     QModelIndex idx = index(row, 0);
     setData(idx, text);
     setData(idx, category, Qt::UserRole);
