@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Aug 2011
  *
- * Copyright (C) 2011-2018  Urs Fleisch
+ * Copyright (C) 2011-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -77,9 +77,9 @@ QString CommandFormatReplacer::getReplacement(const QString& code) const
         { "qmlpath", 'q' }
       };
       const char c = code[0].toLatin1();
-      for (const auto& s2l : shortToLong) {
-        if (s2l.shortCode == c) {
-          name = QString::fromLatin1(s2l.longCode);
+      for (const auto& [longCode, shortCode] : shortToLong) {
+        if (shortCode == c) {
+          name = QString::fromLatin1(longCode);
           break;
         }
       }
@@ -160,7 +160,7 @@ QString CommandFormatReplacer::getToolTip(bool onlyRows)
 
   str += QLatin1String("<tr><td>%d</td><td>%{directory}</td><td>");
   const char* const directoryNameStr =
-      QT_TRANSLATE_NOOP("@default", "Directory name");
+      QT_TRANSLATE_NOOP("@default", "Folder name");
   str += QCoreApplication::translate("@default", directoryNameStr);
   str += QLatin1String("</td></tr>\n");
 
@@ -171,7 +171,7 @@ QString CommandFormatReplacer::getToolTip(bool onlyRows)
 #ifdef CFG_QMLDIR
   str += QLatin1String("<tr><td>%q</td><td>%{qmlpath}</td><td>");
   const char* const qmlBaseDirectoryStr =
-      QT_TRANSLATE_NOOP("@default", "QML base directory");
+      QT_TRANSLATE_NOOP("@default", "QML base folder");
   str += QCoreApplication::translate("@default", qmlBaseDirectoryStr);
   str += QLatin1String("</td></tr>\n");
 #endif
