@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 19-Mar-2011
  *
- * Copyright (C) 2011-2018  Urs Fleisch
+ * Copyright (C) 2011-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -26,7 +26,7 @@
 
 #include "dirproxymodel.h"
 #include <QDateTime>
-#include "filesystemmodel.h"
+#include "taggedfilesystemmodel.h"
 
 /**
  * Constructor.
@@ -59,8 +59,7 @@ Qt::ItemFlags DirProxyModel::flags(const QModelIndex& index) const
  */
 bool DirProxyModel::filterAcceptsRow(int srcRow, const QModelIndex& srcParent) const
 {
-  auto srcModel = qobject_cast<FileSystemModel*>(sourceModel());
-  if (srcModel) {
+  if (auto srcModel = qobject_cast<FileSystemModel*>(sourceModel())) {
     return srcModel->isDir(srcModel->index(srcRow, 0, srcParent));
   }
   return false;
@@ -95,7 +94,7 @@ bool DirProxyModel::lessThan(const QModelIndex& left,
   // The data() in FileSystemModel are String QVariants, therefore
   // QSortFilterProxyModel::lessThan() is of no use here, custom sorting
   // has to be used.
-  Q_ASSERT_X(sourceModel()->metaObject() == &FileSystemModel::staticMetaObject,
+  Q_ASSERT_X(sourceModel()->metaObject() == &TaggedFileSystemModel::staticMetaObject,
              "lessThan", "source model must be FileSystemModel");
   auto fsModel = static_cast<FileSystemModel*>(sourceModel());
   switch (sortColumn()) {
