@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 14 Mar 2014
  *
- * Copyright (C) 2014-2018  Urs Fleisch
+ * Copyright (C) 2014-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -26,6 +26,7 @@
 
 #include "timeeventmodel.h"
 #include <QTextStream>
+#include <QRegularExpression>
 #include "coretaggedfileiconprovider.h"
 #include "eventtimingcode.h"
 
@@ -71,10 +72,10 @@ QVariant TimeEventModel::data(const QModelIndex& index, int role) const
   if (role == Qt::DisplayRole || role == Qt::EditRole) {
     if (index.column() == CI_Time)
       return timeEvent.time;
-    else
-      return timeEvent.data;
-  } else if (role == Qt::BackgroundRole && index.column() == CI_Data &&
-             m_colorProvider) {
+    return timeEvent.data;
+  }
+  if (role == Qt::BackgroundRole && index.column() == CI_Data &&
+      m_colorProvider) {
     return m_colorProvider->colorForContext(index.row() == m_markedRow
         ? ColorContext::Marked : ColorContext::None);
   }
@@ -120,11 +121,11 @@ QVariant TimeEventModel::headerData(
   if (orientation == Qt::Horizontal && section < CI_NumColumns) {
     if (section == CI_Time) {
       return tr("Time");
-    } else if (m_type == EventTimingCodes) {
-      return tr("Event Code");
-    } else {
-      return tr("Text");
     }
+    if (m_type == EventTimingCodes) {
+      return tr("Event Code");
+    }
+    return tr("Text");
   }
   return section + 1;
 }
@@ -156,7 +157,6 @@ int TimeEventModel::columnCount(const QModelIndex& parent) const
  * @param row rows are inserted before this row, if 0 at the begin,
  * if rowCount() at the end
  * @param count number of rows to insert
- * @param parent parent model index, invalid for table models
  * @return true if successful
  */
 bool TimeEventModel::insertRows(int row, int count,
@@ -175,7 +175,6 @@ bool TimeEventModel::insertRows(int row, int count,
  * Remove rows.
  * @param row rows are removed starting with this row
  * @param count number of rows to remove
- * @param parent parent model index, invalid for table models
  * @return true if successful
  */
 bool TimeEventModel::removeRows(int row, int count,
@@ -222,14 +221,18 @@ void TimeEventModel::fromSyltFrame(const Frame::FieldList& fields)
     const Frame::Field& fld = *it;
     if (fld.m_id == Frame::ID_TimestampFormat) {
       unitIsFrames = fld.m_value.toInt() == 1;
+#if QT_VERSION >= 0x060000
+    } else if (fld.m_value.typeId() == QMetaType::QVariantList) {
+#else
     } else if (fld.m_value.type() == QVariant::List) {
+#endif
       synchedData = fld.m_value.toList();
     }
   }
 
   bool newLinesStartWithLineBreak = false;
   QList<TimeEvent> timeEvents;
-  QListIterator<QVariant> it(synchedData);
+  QListIterator it(synchedData);
   while (it.hasNext()) {
     quint32 milliseconds = it.next().toUInt();
     if (!it.hasNext())
@@ -252,8 +255,8 @@ void TimeEventModel::fromSyltFrame(const Frame::FieldList& fields)
       // If the resulting line starts with one of the special characters
       // (' ', '-', '_'), it is escaped with '#'.
       if (str.length() > 0) {
-        QChar ch = str.at(0);
-        if (ch == QLatin1Char(' ') || ch == QLatin1Char('-') ||
+        if (QChar ch = str.at(0);
+            ch == QLatin1Char(' ') || ch == QLatin1Char('-') ||
             ch == QLatin1Char('_')) {
           str.prepend(QLatin1Char('#'));
         }
@@ -285,7 +288,11 @@ void TimeEventModel::toSyltFrame(Frame::FieldList& fields) const
   for (auto it = fields.begin(); it != fields.end(); ++it) {
     if (it->m_id == Frame::ID_TimestampFormat) {
       timeStampFormatIt = it;
+#if QT_VERSION >= 0x060000
+    } else if (it->m_value.typeId() == QMetaType::QVariantList) {
+#else
     } else if (it->m_value.type() == QVariant::List) {
+#endif
       dataIt = it;
     }
   }
@@ -307,7 +314,11 @@ void TimeEventModel::toSyltFrame(Frame::FieldList& fields) const
       }
 
       quint32 milliseconds;
+#if QT_VERSION >= 0x060000
+      if (timeEvent.time.typeId() == QMetaType::QTime) {
+#else
       if (timeEvent.time.type() == QVariant::Time) {
+#endif
         hasMsTimeStamps = true;
         milliseconds = QTime(0, 0).msecsTo(timeEvent.time.toTime());
       } else {
@@ -338,13 +349,17 @@ void TimeEventModel::fromEtcoFrame(const Frame::FieldList& fields)
     const Frame::Field& fld = *it;
     if (fld.m_id == Frame::ID_TimestampFormat) {
       unitIsFrames = fld.m_value.toInt() == 1;
+#if QT_VERSION >= 0x060000
+    } else if (fld.m_value.typeId() == QMetaType::QVariantList) {
+#else
     } else if (fld.m_value.type() == QVariant::List) {
+#endif
       synchedData = fld.m_value.toList();
     }
   }
 
   QList<TimeEvent> timeEvents;
-  QListIterator<QVariant> it(synchedData);
+  QListIterator it(synchedData);
   while (it.hasNext()) {
     quint32 milliseconds = it.next().toUInt();
     if (!it.hasNext())
@@ -370,7 +385,11 @@ void TimeEventModel::toEtcoFrame(Frame::FieldList& fields) const
   for (auto it = fields.begin(); it != fields.end(); ++it) {
     if (it->m_id == Frame::ID_TimestampFormat) {
       timeStampFormatIt = it;
+#if QT_VERSION >= 0x060000
+    } else if (it->m_value.typeId() == QMetaType::QVariantList) {
+#else
     } else if (it->m_value.type() == QVariant::List) {
+#endif
       dataIt = it;
     }
   }
@@ -383,7 +402,11 @@ void TimeEventModel::toEtcoFrame(Frame::FieldList& fields) const
       int code = timeEvent.data.toInt();
 
       quint32 milliseconds;
+#if QT_VERSION >= 0x060000
+      if (timeEvent.time.typeId() == QMetaType::QTime) {
+#else
       if (timeEvent.time.type() == QVariant::Time) {
+#endif
         hasMsTimeStamps = true;
         milliseconds = QTime(0, 0).msecsTo(timeEvent.time.toTime());
       } else {
@@ -413,8 +436,8 @@ void TimeEventModel::markRowForTimeStamp(const QTime& timeStamp)
   int row = 0, oldRow = m_markedRow, newRow = -1;
   for (auto it = m_timeEvents.constBegin(); it != m_timeEvents.constEnd(); ++it) {
     const TimeEvent& timeEvent = *it;
-    QTime time = timeEvent.time.toTime();
-    if (time.isValid() && time >= timeStamp) {
+    if (QTime time = timeEvent.time.toTime();
+        time.isValid() && time >= timeStamp) {
       if (timeStamp.msecsTo(time) > 1000 && row > 0) {
         --row;
       }
@@ -459,7 +482,7 @@ void TimeEventModel::clearMarkedRow()
  */
 void TimeEventModel::fromLrcFile(QTextStream& stream)
 {
-  QRegExp timeStampRe(QLatin1String(
+  QRegularExpression timeStampRe(QLatin1String(
                         R"(([[<])(\d\d):(\d\d)(?:\.(\d{1,3}))?([\]>]))"));
   QList<TimeEvent> timeEvents;
   bool isFirstLine = true;
@@ -485,10 +508,11 @@ void TimeEventModel::fromLrcFile(QTextStream& stream)
 
     QList<QTime> emptyEvents;
     char firstChar = '\0';
-    int pos = timeStampRe.indexIn(line, 0);
-    while (pos != -1) {
-      bool newLine = timeStampRe.cap(1) == QLatin1String("[");
-      QString millisecondsStr = timeStampRe.cap(4);
+    auto it = timeStampRe.globalMatch(line);
+    while (it.hasNext()) {
+      auto match = it.next();
+      bool newLine = match.captured(1) == QLatin1String("[");
+      QString millisecondsStr = match.captured(4);
       int milliseconds = millisecondsStr.toInt();
       if (millisecondsStr.length() == 2) {
         milliseconds *= 10;
@@ -496,18 +520,23 @@ void TimeEventModel::fromLrcFile(QTextStream& stream)
         milliseconds *= 100;
       }
       QTime timeStamp(0,
-                      timeStampRe.cap(2).toInt(),
-                      timeStampRe.cap(3).toInt(),
+                      match.captured(2).toInt(),
+                      match.captured(3).toInt(),
                       milliseconds);
-      int textBegin = pos + timeStampRe.matchedLength();
-
-      pos = timeStampRe.indexIn(line, textBegin);
-      int textLen = pos != -1 ? pos - textBegin : -1;
+      int pos = match.capturedStart();
+      int textBegin = pos + match.capturedLength();
+      int textLen = -1;
+      pos = -1;
+      if (it.hasNext()) {
+        match = it.peekNext();
+        pos = match.capturedStart();
+        textLen = pos - textBegin;
+      }
       QString str = line.mid(textBegin, textLen);
       if (m_type == EventTimingCodes) {
-        EventTimeCode etc =
-            EventTimeCode::fromString(str.toLatin1().constData());
-        if (etc.isValid()) {
+        if (EventTimeCode etc =
+              EventTimeCode::fromString(str.toLatin1().constData());
+            etc.isValid()) {
           timeEvents.append(TimeEvent(timeStamp, etc.getCode()));
         }
       } else {
@@ -526,7 +555,7 @@ void TimeEventModel::fromLrcFile(QTextStream& stream)
           str.prepend(QLatin1Char('_'));
         }
         if (pos != -1) {
-          if (timeStampRe.cap(1) == QLatin1String("<")) {
+          if (match.captured(1) == QLatin1String("<")) {
             if (str.endsWith(QLatin1Char(' ')) ||
                 str.endsWith(QLatin1Char('-'))) {
               firstChar = str.at(str.length() - 1).toLatin1();
@@ -576,7 +605,7 @@ void TimeEventModel::fromTextFile(QTextStream& stream)
  * @param album optional album
  */
 void TimeEventModel::toLrcFile(QTextStream& stream, const QString& title,
-                               const QString& artist, const QString& album)
+                               const QString& artist, const QString& album) const
 {
   bool atBegin = true;
   if (!title.isEmpty()) {
@@ -593,8 +622,7 @@ void TimeEventModel::toLrcFile(QTextStream& stream, const QString& title,
   }
   const auto timeEvents = m_timeEvents;
   for (const TimeEvent& timeEvent : timeEvents) {
-    QTime time = timeEvent.time.toTime();
-    if (time.isValid()) {
+    if (QTime time = timeEvent.time.toTime(); time.isValid()) {
       char firstChar = '\0';
       bool newLine = true;
       QString str;
