@@ -83,6 +83,12 @@ public:
    */
   operator bool() const { return m_warning != None; }
 
+  /**
+   * Get warning of notice.
+   * @return warning.
+   */
+  Warning getWarning() const { return m_warning; }
+
   /**
    * Get translated description of notice.
    * @return description, empty if none.
@@ -93,7 +99,7 @@ public:
    * Get regular expression to validate an ISO 8601 date/time.
    * @return regular expression matching ISO date/time and periods.
    */
-  static const QRegExp& isoDateTimeRexExp();
+  static const QRegularExpression& isoDateTimeRexExp();
 
   /**
    * Check if a picture frame exceeds a given size.
