@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 26 Feb 2012
  *
- * Copyright (C) 2012  Urs Fleisch
+ * Copyright (C) 2012-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef KID3API_H
-#define KID3API_H
+#pragma once
 
 #ifdef KID3_SHARED
 
@@ -56,5 +55,3 @@
 #define KID3_PLUGIN_EXPORT
 
 #endif
-
-#endif // KID3API_H
