@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2018  Urs Fleisch
+ * Copyright (C) 2003-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -28,6 +28,7 @@
 
 #include <QObject>
 #include "kid3api.h"
+#include "config.h"
 
 class QCheckBox;
 class QString;
@@ -66,7 +67,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~ConfigDialogPages() override = default;
+  ~ConfigDialogPages() override = default;
 
   /**
    * Create page with tags settings.
@@ -201,6 +202,10 @@ private:
   QCheckBox* m_playOnDoubleClickCheckBox;
   /** Select file on play checkbox */
   QCheckBox* m_selectFileOnPlayCheckBox;
+#if defined HAVE_QTMULTIMEDIA && QT_VERSION >= 0x060200
+  /** Audio outputs combo box */
+  QComboBox* m_audioOutputComboBox;
+#endif
   /** Commands table */
   ConfigTable* m_commandsTable;
   /** Commands table model */
