@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 3 Jan 2014
  *
- * Copyright (C) 2014-2018  Urs Fleisch
+ * Copyright (C) 2014-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -46,7 +46,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~ConfigurableTreeView() override = default;
+  ~ConfigurableTreeView() override = default;
 
   /**
    * Set visible columns.
@@ -92,6 +92,14 @@ public:
    */
   QList<int> getColumnWidths() const;
 
+  /**
+   * Set the maximum number of columns shown.
+   * This can be used to restrict the number of columns, e.g. to omit columns
+   * with tag data.
+   * @param maxNumColumns maximum number of columns
+   */
+  void setMaxNumColumns(int maxNumColumns) { m_maxNumColumns = maxNumColumns; }
+
   /**
    * Get sort column and order.
    * This method returns the values which can be set with sortByColumn().
@@ -134,7 +142,7 @@ protected:
    * make Return/Enter send activated() also on the Mac.
    * @param event key event
    */
-  virtual void keyPressEvent(QKeyEvent* event) override;
+  void keyPressEvent(QKeyEvent* event) override;
 
 private slots:
   /**
@@ -168,4 +176,5 @@ private:
   QAction* m_customColumnAction;
   QKeySequence m_openParentKey;
   QKeySequence m_openCurrentKey;
+  int m_maxNumColumns;
 };
