@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 2 Jan 2013
  *
- * Copyright (C) 2013-2018  Urs Fleisch
+ * Copyright (C) 2013-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -51,7 +51,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~AbstractListEdit() override = default;
+  ~AbstractListEdit() override = default;
 
   /**
    * Disable editing of items.
