@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 17 Sep 2003
  *
- * Copyright (C) 2003-2018  Urs Fleisch
+ * Copyright (C) 2003-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -53,7 +53,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~FormatBox() override = default;
+  ~FormatBox() override = default;
 
   /**
    * Set the values from a format configuration.
