@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 24-Aug-2010
  *
- * Copyright (C) 2010-2018  Urs Fleisch
+ * Copyright (C) 2010-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -46,6 +46,47 @@ namespace {
 
 const QString zeroTime(QLatin1String(" 0:00"));
 
+/**
+ * Event filter for click on time LCD.
+ */
+class TimeLcdClickHandler : public QObject {
+public:
+  /**
+   * Constructor.
+   * @param playToolBar play tool bar
+   */
+  explicit TimeLcdClickHandler(PlayToolBar* playToolBar)
+    : QObject(playToolBar), m_playToolBar(playToolBar) {}
+
+  ~TimeLcdClickHandler() override = default;
+
+protected:
+  /**
+   * Event filter function, calls PlayToolBar::toggleTimeDisplayMode().
+   *
+   * @param obj watched object
+   * @param event event for object
+   *
+   * @return true if event is filtered.
+   */
+  bool eventFilter(QObject* obj, QEvent* event) override;
+
+private:
+  Q_DISABLE_COPY(TimeLcdClickHandler)
+
+  PlayToolBar* m_playToolBar;
+};
+
+bool TimeLcdClickHandler::eventFilter(QObject* obj, QEvent* event)
+{
+  if (event->type() == QEvent::MouseButtonRelease) {
+    m_playToolBar->toggleTimeDisplayMode();
+    return true;
+  }
+  // standard event processing
+  return QObject::eventFilter(obj, event);
+}
+
 }
 
 /**
@@ -55,7 +96,8 @@ const QString zeroTime(QLatin1String(" 0:00"));
  * @param parent parent widget
  */
 PlayToolBar::PlayToolBar(AudioPlayer* player, QWidget* parent)
-  : QToolBar(parent), m_player(player)
+  : QToolBar(parent), m_player(player),
+    m_timeDisplayMode(TimeDisplayMode::Elapsed)
 {
   setObjectName(QLatin1String("Kid3Player"));
   setWindowTitle(tr("Play"));
@@ -64,13 +106,21 @@ PlayToolBar::PlayToolBar(AudioPlayer* player, QWidget* parent)
   m_pauseIcon = style()->standardIcon(QStyle::SP_MediaPause);
 
   m_playOrPauseAction = new QAction(m_playIcon, tr("Play/Pause"), this);
+  m_playOrPauseAction->setObjectName(QLatin1String("audio_play"));
+  m_playOrPauseAction->setShortcut(Qt::Key_MediaPlay);
   m_stopAction = new QAction(
     style()->standardIcon(QStyle::SP_MediaStop), tr("Stop playback"), this);
+  m_stopAction->setObjectName(QLatin1String("audio_stop"));
+  m_stopAction->setShortcut(Qt::Key_MediaStop);
   m_previousAction = new QAction(
     style()->standardIcon(QStyle::SP_MediaSkipBackward), tr("Previous Track"), this);
+  m_previousAction->setObjectName(QLatin1String("audio_previous"));
+  m_previousAction->setShortcut(Qt::Key_MediaPrevious);
   m_nextAction = new QAction(
     style()->standardIcon(QStyle::SP_MediaSkipForward), tr("Next Track"), this);
-  QAction* closeAction = new QAction(
+  m_nextAction->setObjectName(QLatin1String("audio_next"));
+  m_nextAction->setShortcut(Qt::Key_MediaNext);
+  auto closeAction = new QAction(
     style()->standardIcon(QStyle::SP_TitleBarCloseButton), tr("Close"), this);
 
   auto splitter = new QSplitter(this);
@@ -78,11 +128,11 @@ PlayToolBar::PlayToolBar(AudioPlayer* player, QWidget* parent)
 
   QMediaPlayer* mediaPlayer = m_player->mediaPlayer();
   m_seekSlider = new QSlider(Qt::Horizontal, splitter);
-  m_seekSlider->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
+  m_seekSlider->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
   m_seekSlider->setMinimum(0);
+  m_duration = mediaPlayer->duration();
   // Setting a maximum of 0 crashes with Qt 5.4.0 on Mac OS X.
-  int maximum = mediaPlayer->duration() / 1000;
-  if (maximum > 0) {
+  if (int maximum = m_duration / 1000; maximum > 0) {
     m_seekSlider->setMaximum(maximum);
   }
   connect(m_seekSlider, &QAbstractSlider::actionTriggered,
@@ -107,6 +157,7 @@ PlayToolBar::PlayToolBar(AudioPlayer* player, QWidget* parent)
   m_timeLcd->setFrameStyle(QFrame::NoFrame);
   m_timeLcd->display(zeroTime);
   m_timeLcd->setDigitCount(7);
+  m_timeLcd->installEventFilter(new TimeLcdClickHandler(this));
 
   addAction(m_playOrPauseAction);
   addAction(m_stopAction);
@@ -179,18 +230,26 @@ void PlayToolBar::closeEvent(QCloseEvent*)
  */
 void PlayToolBar::tick(qint64 msec)
 {
-  int hours = msec / (60 * 60 * 1000);
-  int minutes = (msec / (60 * 1000)) % 60;
-  int seconds = (msec / 1000) % 60;
-  if (msec % 1000 >= 500) {
+  qint64 displayedMsecs = msec;
+  QString sign;
+  if (m_timeDisplayMode == TimeDisplayMode::Remaining) {
+    displayedMsecs = qAbs(m_duration - msec);
+    sign = QLatin1String("-");
+  }
+  int hours = displayedMsecs / (60 * 60 * 1000);
+  int minutes = (displayedMsecs / (60 * 1000)) % 60;
+  int seconds = (displayedMsecs / 1000) % 60;
+  if (displayedMsecs % 1000 >= 500) {
     ++seconds;
   }
   if (hours == 0) {
-    m_timeLcd->display(QString(QLatin1String("%1:%2"))
+    m_timeLcd->display(QString(QLatin1String("%1%2:%3"))
+                       .arg(sign)
                        .arg(minutes, 2, 10, QLatin1Char(' '))
                        .arg(seconds, 2, 10, QLatin1Char('0')));
   } else {
-    m_timeLcd->display(QString(QLatin1String("%1:%2:%3"))
+    m_timeLcd->display(QString(QLatin1String("%1%2:%3:%4"))
+                       .arg(sign)
                        .arg(hours, 2, 10, QLatin1Char(' '))
                        .arg(minutes, 2, 10, QLatin1Char('0'))
                        .arg(seconds, 2, 10, QLatin1Char('0')));
@@ -249,9 +308,9 @@ void PlayToolBar::error(QMediaPlayer::Error err)
  */
 void PlayToolBar::durationChanged(qint64 duration)
 {
-  int maximum = duration / 1000;
+  m_duration = duration;
   // Setting a maximum of 0 crashes with Qt 5.4.0 on Mac OS X.
-  if (maximum > 0) {
+  if (int maximum = duration / 1000; maximum > 0) {
     m_seekSlider->setMaximum(maximum);
   }
 }
@@ -306,6 +365,30 @@ void PlayToolBar::toggleMute()
       ? QStyle::SP_MediaVolumeMuted : QStyle::SP_MediaVolume));
 }
 
+/**
+ * Toggle time display mode.
+ */
+void PlayToolBar::toggleTimeDisplayMode()
+{
+  m_timeDisplayMode = m_timeDisplayMode == TimeDisplayMode::Elapsed
+      ? TimeDisplayMode::Remaining : TimeDisplayMode::Elapsed;
+}
+
+/**
+ * Get media player actions.
+ * @return list with named actions for "audio_play", "audio_stop",
+ * "audio_previous", "audio_next".
+ */
+QList<QAction*> PlayToolBar::mediaActions() const
+{
+  return {
+      m_playOrPauseAction,
+      m_stopAction,
+      m_previousAction,
+      m_nextAction
+  };
+}
+
 /**
  * Update display and button state when the current track is changed.
  *
@@ -322,9 +405,9 @@ void  PlayToolBar::trackChanged(const QString& filePath,
   m_previousAction->setEnabled(hasPrevious);
   m_nextAction->setEnabled(hasNext);
 
-  int maximum = m_player->mediaPlayer()->duration() / 1000;
+  m_duration = m_player->mediaPlayer()->duration();
   // Setting a maximum of 0 crashes with Qt 5.4.0 on Mac OS X.
-  if (maximum > 0) {
+  if (int maximum = m_duration / 1000; maximum > 0) {
     m_seekSlider->setMaximum(maximum);
   }
 }
