@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 24-Aug-2010
  *
- * Copyright (C) 2010-2018  Urs Fleisch
+ * Copyright (C) 2010-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -42,6 +42,12 @@ class QSlider;
 class PlayToolBar : public QToolBar {
   Q_OBJECT
 public:
+  /** What time is displayed in m_timeLcd. */
+  enum class TimeDisplayMode {
+    Elapsed,  /**< Elapsed time */
+    Remaining /**< Remaining time */
+  };
+
   /**
    * Constructor.
    *
@@ -53,7 +59,19 @@ public:
   /**
    * Destructor.
    */
-  virtual ~PlayToolBar() override;
+  ~PlayToolBar() override;
+
+  /**
+   * Toggle time display mode.
+   */
+  void toggleTimeDisplayMode();
+
+  /**
+   * Get media player actions.
+   * @return list with named actions for "audio_play", "audio_stop",
+   * "audio_previous", "audio_next".
+   */
+  QList<QAction*> mediaActions() const;
 
 signals:
   /**
@@ -137,7 +155,7 @@ protected:
   /**
    * Stop sound when window is closed.
    */
-  virtual void closeEvent(QCloseEvent*) override;
+  void closeEvent(QCloseEvent*) override;
 
 private:
   QIcon m_playIcon;
@@ -156,4 +174,7 @@ private:
   QAction* m_muteAction;
   QSlider* m_seekSlider;
   QSlider* m_volumeSlider;
+
+  qint64 m_duration;
+  TimeDisplayMode m_timeDisplayMode;
 };
