@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 13 Jan 2017
  *
- * Copyright (C) 2017-2018  Urs Fleisch
+ * Copyright (C) 2017-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -47,7 +47,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~ProgressWidget() override = default;
+  ~ProgressWidget() override = default;
 
   /**
    * Set title.
