@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 15 Mar 2014
  *
- * Copyright (C) 2014  Urs Fleisch
+ * Copyright (C) 2014-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef TIMEEVENTEDITOR_H
-#define TIMEEVENTEDITOR_H
+#pragma once
 
 #include <QWidget>
 #include "frame.h"
@@ -62,7 +61,7 @@ public:
   /**
    * Destructor.
    */
-  virtual ~TimeEventEditor();
+  ~TimeEventEditor() override = default;
 
   /**
    * Set time event model.
@@ -75,13 +74,13 @@ protected:
    * Connect to player when editor is shown.
    * @param event event
    */
-  virtual void showEvent(QShowEvent* event);
+  void showEvent(QShowEvent* event) override;
 
   /**
    * Disconnect from player when editor is hidden.
    * @param event event
    */
-  virtual void hideEvent(QHideEvent* event);
+  void hideEvent(QHideEvent* event) override;
 
 private slots:
   /**
@@ -172,5 +171,3 @@ private:
   QByteArray m_byteArray;
   bool m_fileIsPlayed;
 };
-
-#endif // TIMEEVENTEDITOR_H
