@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 13 Sep 2005
  *
- * Copyright (C) 2005-2007  Urs Fleisch
+ * Copyright (C) 2005-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef DISCOGSCONFIG_H
-#define DISCOGSCONFIG_H
+#pragma once
 
 #include "serverimporterconfig.h"
 
@@ -42,10 +41,12 @@ public:
   /**
    * Destructor.
    */
-  virtual ~DiscogsConfig();
+  ~DiscogsConfig() override;
+
+private:
+  friend DiscogsConfig&
+  StoredConfig<DiscogsConfig, ServerImporterConfig>::instance();
 
   /** Index in configuration storage */
   static int s_index;
 };
-
-#endif // DISCOGSCONFIG_H
