@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 21 Jun 2014
  *
- * Copyright (C) 2014-2018  Urs Fleisch
+ * Copyright (C) 2014-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -37,7 +37,7 @@
  * The following source IDs are supported (starting with "image://kid3/"):
  * - "fileicon/" followed by "null", "notag", "v1", "v2", "v1v2", or "modified",
  * - "data" followed by a changing string to force loading of the image set with
- *   TaggedFileIconProvider::setImageData().
+ *   CoreTaggedFileIconProvider::setImageData().
  */
 class QmlImageProvider : public QQuickImageProvider, public PixmapProvider {
 public:
@@ -45,12 +45,12 @@ public:
    * Constructor.
    * @param iconProvider icon provider to use
    */
-  explicit QmlImageProvider(TaggedFileIconProvider* iconProvider);
+  explicit QmlImageProvider(CoreTaggedFileIconProvider* iconProvider);
 
   /**
    * Destructor.
    */
-  virtual ~QmlImageProvider() override = default;
+  ~QmlImageProvider() override = default;
 
   /**
    * Request a pixmap.
@@ -60,6 +60,6 @@ public:
    * @param requestedSize the size requested via the Image.sourceSize property
    * @return pixmap for ID.
    */
-  virtual QPixmap requestPixmap(const QString& id, QSize* size,
-                                const QSize& requestedSize) override;
+  QPixmap requestPixmap(const QString& id, QSize* size,
+                        const QSize& requestedSize) override;
 };
