@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 27 Jul 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2024  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -29,17 +29,17 @@
 #include "flacfile.hpp"
 #include "tagconfig.h"
 
-#if QT_VERSION < 0x050000
-Q_EXPORT_PLUGIN2(OggFlacMetadataPlugin, OggFlacMetadataPlugin)
-#endif
+namespace {
 
 #ifdef HAVE_VORBIS
-static const QLatin1String OGG_KEY("OggMetadata");
+const QLatin1String OGG_KEY("OggMetadata");
 #endif
 #ifdef HAVE_FLAC
-static const QLatin1String FLAC_KEY("FlacMetadata");
+const QLatin1String FLAC_KEY("FlacMetadata");
 #endif
 
+}
+
 /*!
  * Constructor.
  * @param parent parent object
@@ -49,13 +49,6 @@ OggFlacMetadataPlugin::OggFlacMetadataPlugin(QObject* parent) : QObject(parent)
   setObjectName(QLatin1String("OggFlacMetadata"));
 }
 
-/**
- * Destructor.
- */
-OggFlacMetadataPlugin::~OggFlacMetadataPlugin()
-{
-}
-
 /**
  * Get name of factory, the same as the QObject::objectName() of the plugin.
  * @return factory name.
@@ -71,14 +64,14 @@ QString OggFlacMetadataPlugin::name() const
  */
 QStringList OggFlacMetadataPlugin::taggedFileKeys() const
 {
-  return QStringList()
+  return {
 #ifdef HAVE_VORBIS
-      << OGG_KEY
+      OGG_KEY,
 #endif
 #ifdef HAVE_FLAC
-      << FLAC_KEY
+      FLAC_KEY,
 #endif
-         ;
+  };
 }
 
 /**
@@ -128,8 +121,8 @@ TaggedFile* OggFlacMetadataPlugin::createTaggedFile(
   Q_UNUSED(features)
 #ifdef HAVE_VORBIS
   if (key == OGG_KEY) {
-    QString ext = fileName.right(4).toLower();
-    if (ext == QLatin1String(".oga") || ext == QLatin1String(".ogg"))
+    if (QString ext = fileName.right(4).toLower();
+        ext == QLatin1String(".oga") || ext == QLatin1String(".ogg"))
       return new OggFile(idx);
   }
 #endif
@@ -139,7 +132,7 @@ TaggedFile* OggFlacMetadataPlugin::createTaggedFile(
       return new FlacFile(idx);
   }
 #endif
-  return 0;
+  return nullptr;
 }
 
 /**
@@ -154,12 +147,12 @@ OggFlacMetadataPlugin::supportedFileExtensions(const QString& key) const
 {
 #ifdef HAVE_VORBIS
   if (key == OGG_KEY) {
-    return QStringList() << QLatin1String(".oga") << QLatin1String(".ogg");
+    return {QLatin1String(".oga"), QLatin1String(".ogg")};
   }
 #endif
 #ifdef HAVE_FLAC
   if (key == FLAC_KEY) {
-    return QStringList() << QLatin1String(".flac");
+    return {QLatin1String(".flac")};
   }
 #endif
   return QStringList();
