@@ -40,9 +40,9 @@ public:
 class AACFileTypeResolver : public TagLib::FileRef::FileTypeResolver
 {
 public:
-    virtual TagLib::File *createFile(const char *fileName,
-            bool readAudioProperties,
-            TagLib::AudioProperties::ReadStyle audioPropertiesStyle) const override;
+  TagLib::File *createFile(const char *fileName,
+                           bool readProperties,
+                           TagLib::AudioProperties::ReadStyle propertiesStyle) const override;
     virtual ~AACFileTypeResolver() {}
 };
 
