@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 09 Oct 2012
  *
- * Copyright (C) 2012-2018  Urs Fleisch
+ * Copyright (C) 2012-2021  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -43,7 +43,8 @@ void TestDiscogsImporter::testQueryAlbums()
   QString text, category, id;
   albumModel->getItem(0, text, category, id);
   QCOMPARE(text, QString(QLatin1String("Wizard - Odin (2003) [CD, Album, Enh, Ltd, Dig]")));
-  QCOMPARE(category, QString(QLatin1String("Wizard-Odin/release")));
+  QVERIFY(QStringList({QLatin1String("Wizard-Odin/release"), QLatin1String("release")})
+          .contains(category));
   QVERIFY(!id.isEmpty());
 }
 
@@ -72,7 +73,7 @@ void TestDiscogsImporter::testQueryTracks()
           << QLatin1String("3:53") << QLatin1String("4:52")
           << QLatin1String("5:05") << QLatin1String("");
   QCOMPARE(m_trackDataModel->rowCount(), 14);
-  for (int row = 0; row < 11; ++row) {
+  for (int row = 0; row < 14; ++row) {
     QCOMPARE(m_trackDataModel->index(row, 0).data().toString(), lengths.at(row));
     QCOMPARE(m_trackDataModel->index(row, 3).data().toInt(), row + 1);
     QCOMPARE(m_trackDataModel->index(row, 4).data().toString(), titles.at(row));
@@ -82,14 +83,22 @@ void TestDiscogsImporter::testQueryTracks()
              QString(QLatin1String("Odin")));
     QCOMPARE(m_trackDataModel->index(row, 7).data().toInt(), 2003);
     QCOMPARE(m_trackDataModel->index(row, 8).data().toString(),
-             QString(QLatin1String("Heavy Metal")));
-    QCOMPARE(m_trackDataModel->index(row, 10).data().toString(),
-             QString(QLatin1String("LMP 0303-054 Ltd. CD")));
+             QString(QLatin1String("Heavy Metal|Power Metal|Speed Metal")));
+    QCOMPARE(m_trackDataModel->index(row, 9).data().toString(),
+             QString(QLatin1String("")));
+    auto arranger = m_trackDataModel->index(row, 10).data().toString();
+    QVERIFY(arranger.contains(QLatin1String("Producer|Peter Fundeis")) &&
+            arranger.contains(QLatin1String("Mixer|Piet Sielck")));
     QCOMPARE(m_trackDataModel->index(row, 11).data().toString(),
-             QString(QLatin1String("CD, Album, Limited Edition, Enhanced, Digipak")));
-    QCOMPARE(m_trackDataModel->index(row, 12).data().toString(),
+             QString(QLatin1String("Wizard")));
+    QVERIFY(m_trackDataModel->index(row, 12).data().toString()
+            .contains(QLatin1String("CD")));
+    auto performer = m_trackDataModel->index(row, 13).data().toString();
+    QVERIFY(performer.contains(QLatin1String("Bass|Volker Leson")) &&
+            performer.contains(QLatin1String("Vocals|Sven D'Anna")));
+    QCOMPARE(m_trackDataModel->index(row, 14).data().toString(),
              QString(QLatin1String("LMP")));
-    QCOMPARE(m_trackDataModel->index(row, 13).data().toString(),
+    QCOMPARE(m_trackDataModel->index(row, 15).data().toString(),
              QString(QLatin1String("Germany")));
   }
 }
